#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Jun  1 08:38:35 2017

@author: lessig
"""


import numpy as np
import scipy
import matplotlib.pyplot as plt

import spherical_harmonics


Lmax = 32
coeffs = np.zeros( (2,Lmax,Lmax) )

pidx = 0
for p in [16,32] :
    for l in range( Lmax) :
        for m in range( l) :
    
            # define integrand
            integrand = (lambda theta, phi : np.power( np.cos(theta), p) 
                            * spherical_harmonics.ylm( l, m, theta, phi).real 
                            * np.sin(theta))
            
            # compute integral
            ival = (scipy.integrate.nquad( integrand, 
                                  [[0, np.pi/2.0],[0,2*np.pi]], full_output=True))
    
            coeffs[pidx,l,m] = ival[0]
            
    pidx += 1
    
             
# because of radial symmetry only the m=0 coeffs are nonzero        
plt.figure(frameon=False)
plt.plot( coeffs[0,:,0], 'r')
plt.plot( coeffs[1,:,0], 'b')
plt.legend( ['p=16', 'p=32'])
plt.xlabel('l')
plt.savefig( 'figures/phong.pdf')
plt.show()
